import { authorize } from '@faable/auth-helpers-axios';
import axios from 'axios';
import { log } from '../lib/log.js';

const api = authorize({
    client: axios.create({ baseURL: "https://api-content.faable.link" }),
});
const get_post_by_slug = async (slug, box) => {
    try {
        const content = await api.get(`/content/${slug}`, {
            params: { mode: "slug", box, cache: false },
        });
        return content.data;
    }
    catch (error) {
        const e = error;
        // 404 is a valid response if content does not exist
        if (e.response.status == 404) {
            return false;
        }
        throw e;
    }
};
const create = async (post, box) => {
    try {
        const res = await api.post("/content", { box, ...post });
        return res.data;
    }
    catch (error) {
        const e = error;
        console.log(e.response.data);
        throw new Error(`Cannot create '${post.slug}' in [box:${box}]`);
    }
};
const delete_post = async (id) => {
    const res = await api.delete(`/content/${id}`);
    return res.data;
};
const update_current_post = async (post_id, data) => {
    try {
        const res = await api.post(`/content/${post_id}`, {
            ...data.post,
            file_checksum: data.md5,
        });
        log.info(`Updated [${res.data.box}][${res.data.id}] ${res.data.slug}`);
        return res.data;
    }
    catch (error) {
        const e = error;
        console.log(e.response.data);
        throw new Error(`Cannot update ${post_id}`);
    }
};
const upsert_post = async (slug, extracted, box) => {
    if (!slug) {
        throw new Error("Missing slug on post");
    }
    // Try to find content
    const post = await get_post_by_slug(slug, box);
    if (post) {
        // Update post
        await update_current_post(post.id, extracted);
    }
    else {
        console.log(`Not found, creating new`);
        // Create the content if not found
        const created_content = await create({
            slug,
            ...extracted.post,
        }, box);
        log.info(`Created [box:${box}] ${created_content.slug}`);
    }
};
const list_all_in_box = async (params) => {
    const req = {
        method: "GET",
        url: "/content",
        params: {
            box: params.box,
        },
    };
    const pages = [];
    let res;
    do {
        res = await api.request({
            ...req,
            params: { ...req.params, next: res?.data?.next },
        });
        pages.push(res.data);
    } while (res.data.next);
    return pages.map((page) => page.results).flat();
};

export { delete_post, list_all_in_box, upsert_post };
